.. physics documentation master file, created by
   sphinx-quickstart on Mon Aug 19 00:13:44 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

UBC Solar Simulation Documentation
=====================


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   README.md
   api

.. include:: ../../README.md
  :parser: myst_parser.sphinx_
  :start-after: <!-- marker-index-start -->
  :end-before: <!-- marker-index-end -->
